@@ -3,13 +3,14 @@
 { package P;
 	# next line needed for P.pm to be runnable & pass it's tests
 	BEGIN{ $::INC{__PACKAGE__.".pm"} = __FILE__."#__LINE__"};
-	use 5.10.0;
+
 	use warnings;
-	our $VERSION='1.1.2';
+	our $VERSION='1.1.3';
 	use utf8;
 # vim=:SetNumberAndWidth
 
 	# RCS $Revision: 1.38 $ -  $Date: 2013-09-30 18:47:44-07 $
+	# 1.1.3		- [#$@%&!!!]
 	# 1.1.2		- Second try for test in P.t to get prereq's right
 	# 1.1.1   - Fix rest of (rt#89050)
 	# 1.1.0		- Fixed Internal bug#001, below & embedded \n@end of int. str
@@ -332,10 +333,10 @@
 
 {
 	package main;
-  use 5.8.0;
-	use utf8;
 
 	unless ((caller 0)[0]) {
+		binmode P::DATA, ":utf8";
+		binmode *STDOUT, ":utf8";
     $_=do{ $/=undef, <P::DATA>};
 		close P::DATA;
 		our @globals;
@@ -360,7 +361,7 @@ P  -   Safer, friendlier sprintf/printf+say
 
 =head1 VERSION
 
-Version  "1.1.2"
+Version  "1.1.3"
 
 =head1 SYNOPSIS
 
@@ -562,7 +563,8 @@ package P;
 __DATA__
 # line ' .__LINE__ . ' "' ' __FILE__ . "\"\n" . '
 use utf8;
-use utf8::all;
+use open IN => q(:utf8);
+use open OUT => q(:utf8);
 foreach (qw{STDERR STDOUT}) {select *$_; $|=1};
 use strict; use warnings; 
 use P;
@@ -666,7 +668,7 @@ case "truncate embedded float" && do		# case 12 - embedded float
 };
 
 case "test mixed digit string" && do		# case 13 - embed foreign digits
-{	my $p="3.ⅰⅳⅰⅴⅸ";
+{	use utf8;my $p="3.ⅰⅳⅰⅴⅸ";
 	P "embed roman pi = %s", [$p];
 };
 # vim: ts=2 sw=2
